<?php
/* Copyright (C) 2004-2017 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2017 Mikael Carlavan <contact@mika-carl.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *  \file       htdocs/prixmasse/admin/setup.php
 *  \ingroup    prixmasse
 *  \brief      Admin page
 */


$res=@include("../../main.inc.php");                   // For root directory
if (! $res) $res=@include("../../../main.inc.php");    // For "custom" directory

// Libraries
require_once DOL_DOCUMENT_ROOT . "/core/lib/admin.lib.php";
dol_include_once("/prixmasse/lib/prixmasse.lib.php");

dol_include_once("/prixmasse/class/prixmasse.produit.class.php");


// Translations
$langs->load("prixmasse@prixmasse");

// Access control
if (! $user->admin) accessforbidden();

// Parameters
$action = GETPOST('action', 'alpha');
$fk_produit = GETPOST('fk_produit', 'int');

/*
 * Actions
 */

if ($action == 'add')
{
	$prixMasseProduit = new PrixMasseProduit($db);
	$prixMasseProduit->fk_produit = $fk_produit;
	$prixMasseProduit->create($user);
}

if ($action == 'delete')
{
	$prixMasseProduit = new PrixMasseProduit($db);
	$prixMasseProduit->fetch(0, $fk_produit);
	$prixMasseProduit->delete($user);	
}

$prixMasseProduit = new PrixMasseProduit($db);
$prixMasseProduit->fetch();

$produits = $prixMasseProduit->produits;

/*
 * View
 */

llxHeader('', $langs->trans('PrixMasseSetup'));

// Subheader
$linkback = '<a href="' . DOL_URL_ROOT . '/admin/modules.php">' . $langs->trans("BackToModuleList") . '</a>';

print load_fiche_titre($langs->trans('PrixMasseSetup'), $linkback);

// Configuration header
$head = prixmasse_prepare_admin_head();
dol_fiche_head(
	$head,
	'settings',
	$langs->trans("ModulePrixMasseName"),
	0,
	"prixmasse@prixmasse"
);

// Setup page goes here
echo $langs->trans("PrixMasseSetupPage");


print load_fiche_titre($langs->trans("ProductToExclude"),'','');

$form = new Form($db);

print '<table class="noborder" width="100%">';
print '<tbody>';
print '<tr class="liste_titre">';
print '<td>'.$langs->trans("Name").'</td>';
print '<td align="center">'.$langs->trans("Action").'</td>';
print "</tr>\n";

if (sizeof($produits))
{
	foreach ($produits as $pid => $produit)
	{
		print '<tr class="oddeven">';
		print '<td>';
		print $produit->getNomUrl();
		print '</td>';
		print '<td align="center">';
		print '<a href="'.$_SERVER['PHP_SELF'].'?action=delete&fk_produit='.$pid.'">'.img_delete().'</a>';
		print '</td>';
		print '</tr>';
	}
}
else
{
	print '<tr class="oddeven">';
	print '<td colspan="2">';
	print $langs->trans('NoProductsExcluded');
	print '</td>';
	print '</tr>';	
}

print '<form action="'.$_SERVER["PHP_SELF"].'" method="POST">';
print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
print '<input type="hidden" name="action" value="add">';

print '<tr class="oddeven">';
print '<td>';
print $form->select_produits('', 'fk_produit', '', 0, 0, -1, 2, '', 1);
print '</td>';
print '<td align="center">';
print '<input type="submit" class="button" value="'.$langs->trans("AddProduct").'" name="Button">';
print '</td>';
print '</tr>';

print '</form>';
print '</tbody>';
print '</table>';


// Page end
dol_fiche_end();
llxFooter();
