<?php
/* Copyright (C) 2004-2017 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2017 Mikael Carlavan <contact@mika-carl.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *  \file       htdocs/prixmasse/class/actions_prixmasse.class.php
 *  \ingroup    prixmasse
 *  \brief      File of class to manage actions on propal
 */

require_once DOL_DOCUMENT_ROOT.'/core/class/commonobject.class.php';
require_once DOL_DOCUMENT_ROOT.'/product/class/product.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/notify.class.php';
require_once DOL_DOCUMENT_ROOT.'/comm/propal/class/propal.class.php';

dol_include_once("/prixmasse/class/prixmasse.class.php");
dol_include_once("/prixmasse/class/prixmasse.produit.class.php");

class ActionsPrixMasse
{ 

	function printObjectLineTitle($parameters, &$object, &$action, $hookmanager)
	{
		global $langs, $db, $mysoc, $conf;
		
		$langs->load('prixmasse@prixmasse');
	
		$lines = $object->lines;

		$prixMasseProduit = new PrixMasseProduit($db);
		$prixMasseProduit->fetch();

		$produits = $prixMasseProduit->produits;

		for ($i = 0; $i < sizeof($lines); $i++)
		{
			$line = $lines[$i];

			if ($line->fk_product > 0 && in_array($line->fk_product, array_keys($produits)))
			{
				$object->lines[$i]->product_label .= ' '.img_picto($langs->trans('PriceModificationDoesNotApply'),'warning.png');						
			}
    	}		

		$this->resprints = '';
		return 0;		
	}

	function doActions($parameters, &$object, &$action, $hookmanager)
	{
		global $langs, $db, $mysoc, $conf, $user;
		
		$langs->load('prixmasse@prixmasse');
		$error = 0;




		if ($action == 'confirm_addmassprice' && GETPOST('confirm') == 'yes')
		{
			if (!GETPOST('mass_percent') && !GETPOST('total_ht_after'))
			{	
				setEventMessages($langs->trans('MassPercentIsEmpty'), null, 'errors');
			}
			else
			{

				$total_ht_after = GETPOST('total_ht_after') ? price2num(GETPOST('total_ht_after')) : 0;
				$mass_percent = GETPOST('mass_percent') ? price2num(GETPOST('mass_percent')) : 0;

				$mass_factor = 1;
				$total_ht_before = $object->total_ht;
				$total_ht = $object->total_ht;
				if ($mass_percent != 0 && empty($total_ht_after))
				{
					$total_ht_after = $total_ht_before * (1 + $mass_percent/100);
					$total_ht_after = price2num(price($total_ht_after), 'MT');
				}

				if ($total_ht_before > 0)
				{
					$prixMasseProduit = new PrixMasseProduit($db);
					$prixMasseProduit->fetch();
			
					$produits = $prixMasseProduit->produits;
				
					$lines = $object->lines;
			
					for ($i = 0; $i < sizeof($lines); $i++)
					{
						$line = $lines[$i];
			
						if ($line->fk_product > 0 && in_array($line->fk_product, array_keys($produits)))
						{
							$total_ht_after -= $line->total_ht;
							$total_ht_before -= $line->total_ht;
						}
					}


					$mass_percent = $total_ht_before > 0 ? 100*($total_ht_after/$total_ht_before - 1) : 0;
				}	
							

				$mass_factor = (1 + $mass_percent/100);

				$prixmasse = new PrixMasse($db);
				$result = $prixmasse->applyMassMod($object, $mass_factor);
				
				$total_ht_after = $object->total_ht;

				if ($result > 0)
				{
					$prixmasse = new PrixMasse($db);
					$prixmasse->fk_object = $object->id;
					$prixmasse->percent = $mass_percent;
					$prixmasse->total_ht_after = $total_ht_after;
					$prixmasse->total_ht_before = $total_ht;

					if ($prixmasse->create($user) > 0)
					{
						setEventMessages($langs->trans("MassPercentApplied"), null, 'mesgs');
					}
					else
					{
						setEventMessages($prixmasse->error, $prixmasse->errors, 'errors');
					}
					
				}
				else
				{
					setEventMessages($object->error, $object->errors, 'errors');
				}
				

				$object->fetch_lines();
			}
		}

		$this->resprints = '';
		return 0;
		
	}

	function addMoreActionsButtons($parameters, &$object, &$action, $hookmanager)
	{
		global $langs, $db, $mysoc, $conf, $user;
		
		$langs->load('prixmasse@prixmasse');
				
		if ($object->statut == Propal::STATUS_DRAFT && $user->rights->prixmasse->creer)
		{
			print '<div class="inline-block divButAction"><a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '&amp;action=addmassprice">' . $langs->trans('AddMassPrice') . '</a></div>';
		}
	
		if (!empty($conf->propalehistory->enabled))
		{
			// Propalehistory compatibilty
			$actionATM = GETPOST('actionATM'); //restaurer supprimer  

			if ($actionATM == 'viewVersion')
			{
				print '<script type="text/javascript">'."\r\n";
	    		print '$(document).ready(function() {'."\r\n";
	    		print '$.urlParam = function(name, url){'."\r\n";
				print 'var results = new RegExp(\'[\?&]\' + name + \'=([^&#]*)\').exec(url);'."\r\n";
				print 'return results[1] || 0;'."\r\n";
				print '}'."\r\n";

				print '		$( "#butSupprimer" ).click(function(e){'."\r\n";
				print ' 		e.preventDefault();'."\r\n";
				print '			var href = $(this).attr(\'href\');'."\r\n";
				print '			var idVersion = $.urlParam(\'idVersion\', href);'."\r\n";
				print '			var url = \''.dol_buildpath('/prixmasse/propal.php?actionATM=supprimer&id='.$object->id,1).'&idVersion=\'+ idVersion;'."\r\n";
				print ' 		$.get(url, function(data){ window.location.href = href; });'."\r\n";
				print '		});'."\r\n";
				print '		'."\r\n";
				print '		$( "#butRestaurer" ).click(function(e){'."\r\n";
				print ' 		e.preventDefault();'."\r\n";
				print '			var href = $(this).attr(\'href\');'."\r\n";
				print '			var idVersion = $.urlParam(\'idVersion\', href);'."\r\n";
				print '			var url = \''.dol_buildpath('/prixmasse/propal.php?actionATM=restaurer&id='.$object->id,1).'&idVersion=\'+ idVersion;'."\r\n";
				print ' 		$.get(url, function(data){ window.location.href = href; });'."\r\n";
				print '		});'."\r\n";
	    		print '});'."\r\n";
	    		print '</script>'."\r\n";

			}

			
		}

		$this->resprints = '';
		return 0;
	}
	

	function formConfirm($parameters, &$object, &$action, $hookmanager)
	{
		global $langs, $db, $mysoc, $conf;
		
		$form = new Form($db);

		$langs->load('prixmasse@prixmasse');

		$formconfirm = '';


		if ($action == 'addmassprice')
		{
			$prixmasse = new PrixMasse($db);
        	$prixmasse->fetch('', $object->id);

			$mods = $prixmasse->mods;
		
			$formquestion = array();

			if (sizeof($mods))
			{
				$prixmasse = array_shift($mods);
				$formquestion['text'] = $langs->trans('OneModificationExists', dol_print_date($prixmasse->date_creation, 'day'), price($prixmasse->percent_display, 0, $langs, 1, -1, 2), $object->ref);
			}

			// Create an array for form
			$formquestion[] = array(
				'type' => 'text',
				'name' => 'mass_percent',
				'label' => $langs->trans("MassPercent"),
				'value' => ''
			);
		
			$formquestion[] = array(
				'type' => 'text',
				'name' => 'total_ht_after',
				'label' => $langs->trans("TotalHTAfter"),
				'value' => ''
			);


			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"] . '?id=' . $object->id, $langs->trans('AddMassPriceTitle'), $langs->trans('ConfirmAddMassPrice', $object->ref), 'confirm_addmassprice', $formquestion, 'yes', 1, 280);			
		}


		$this->resprints = $formconfirm;
		return 0;		
	}


}


