<?php
/* Copyright (C) 2004-2017 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2017 Mikael Carlavan <contact@mika-carl.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *  \file       htdocs/prixmasse/product.php
 *  \ingroup    prixmasse
 *  \brief      Page to show product set
 */



$res=@include("../main.inc.php");                   // For root directory
if (! $res) $res=@include("../../main.inc.php");    // For "custom" directory
require_once DOL_DOCUMENT_ROOT.'/product/class/product.class.php';
require_once DOL_DOCUMENT_ROOT.'/comm/propal/class/propal.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/propal.lib.php';

dol_include_once("/prixmasse/class/prixmasse.class.php");

$langs->load("prixmasse@prixmasse");

$langs->load('companies');
$langs->load('propal');
$langs->load('compta');
$langs->load('bills');
$langs->load('orders');
$langs->load('products');
$langs->load("deliveries");
$langs->load('sendings');

$id = GETPOST('id', 'int');
$ref = GETPOST('ref', 'alpha');

$rowid = GETPOST('rowid', 'int');
$socid = GETPOST('socid', 'int');

$action = GETPOST('action','aZ09');
$actionATM = GETPOST('actionATM'); //restaurer supprimer  
$idVersion = GETPOST('idVersion');

$result=restrictedArea($user,'prixmasse');

$object = new Propal($db);
if ($id > 0 || ! empty($ref)) $object->fetch($id, $ref);


if (!empty($actionATM))
{
    if ($actionATM == 'restaurer')
    {
        $prixmasse = new PrixMasse($db);
        echo $prixmasse->loadFromVersion($object->id, $idVersion);
    }
    else if ($actionATM == 'supprimer')
    {
        $prixmasse = new PrixMasse($db);
        echo $prixmasse->deleteFromVersion($object->id, $idVersion);                     
    }
}
else
{
    /*
     * Actions
     */

    $form = new Form($db);




    if ($action == 'confirm_delmod' && GETPOST('confirm') == 'yes')
    {
        $prixmasse = new PrixMasse($db);
        $prixmasse->fetch($rowid);


        $mass_percent = $prixmasse->percent;
        $mass_factor = 1/(1 + $mass_percent/100);

        $result = $prixmasse->delete($user);

        if ($result < 0)
        {
            setEventMessages($prixmasse->error, $prixmasse->errors, 'errors');   
        } 
        else
        {
            if ($prixmasse->applyMassMod($object, $mass_factor) > 0)
            {
                setEventMessages($langs->trans("MassPercentDeleted"), null, 'mesgs');
            }
            else
            {
                setEventMessages($object->error, $object->errors, 'errors');
            }
        }

    }

    /*
     *  View
     */

    $helpurl = '';

    $title = $langs->trans('Proposal');
    $help_url = 'EN:Commercial_Proposals|FR:Proposition_commerciale|ES:Presupuestos';

    llxHeader('', $title, $help_url);

    if ($action == 'delmod')
    {
        $prixmasse = new PrixMasse($db);
        $prixmasse->fetch($rowid);

        print $form->formconfirm($_SERVER["PHP_SELF"] . '?id=' . $object->id.'&rowid='.$rowid, $langs->trans('DeleteMassMod'), $langs->trans('ConfirmDeleteMassMod', dol_print_date($prixmasse->date_creation, 'day'), price($prixmasse->percent_display, 0, $langs, 1, -1, 2), $object->ref), 'confirm_delmod', '', 'yes', 1); 

    }


    if ($id > 0 || ! empty($ref))
    {
        $prixmasse = new PrixMasse($db);
        $prixmasse->fetch('', $object->id);

        /*
         * Affichage onglets
         */
        if (! empty($conf->notification->enabled)) $langs->load("mails");

        $head = propal_prepare_head($object);
        dol_fiche_head($head, 'prixmasse', $langs->trans('Proposal'), -1, 'propal');

        $linkback = '<a href="' . DOL_URL_ROOT . '/comm/propal/list.php?restore_lastsearch_values=1' . (! empty($socid) ? '&socid=' . $socid : '') . '">' . $langs->trans("BackToList") . '</a>';
        $shownav = 1;
        if ($user->societe_id && ! in_array('product', explode(',',$conf->global->MAIN_MODULES_FOR_EXTERNAL))) $shownav=0;

        dol_banner_tab($object, 'ref', $linkback, $shownav, 'ref');

        dol_fiche_end();

        $mods = $prixmasse->mods;

        print load_fiche_titre($langs->trans("MassModificationsHist"), '', '');

        print '<div class="div-table-responsive-no-min">';
        print '<table width="100%" id="tablelines" class="liste">'."\n";

        print '<tr class="liste_titre nodrag nodrop">';
        print_liste_field_titre('ModDate',$_SERVER["PHP_SELF"]);
        print_liste_field_titre('ModUser',$_SERVER["PHP_SELF"]);
        print_liste_field_titre('ModTotalHTBefore',$_SERVER["PHP_SELF"]);
        print_liste_field_titre('ModPercent',$_SERVER["PHP_SELF"]);
        print_liste_field_titre('ModTotalHTAfter',$_SERVER["PHP_SELF"]);
        print_liste_field_titre('ModAction',$_SERVER["PHP_SELF"]);
        print "</tr>\n";

        if (is_array($mods) && sizeof($mods))
        {
            foreach ($mods as $i => $m)
            {            
                print '<tr class="oddeven">';
                print '<td align="left">'.dol_print_date($m->date_creation, 'day').'</td>';
                print '<td align="left">'.$m->fk_user.'</td>';
                print '<td align="left">'.price($m->total_ht_before, 0, $langs, 1, -1, -1, $conf->currency) .'</td>';
                print '<td align="left">'.price($m->percent_display, 0, $langs, 1, -1, 2).' %</td>';
                print '<td align="left">'.price($m->total_ht_after, 0, $langs, 1, -1, -1, $conf->currency) .'</td>';
                print '<td align="left">';

                if ($i == 0 && $object->statut == Propal::STATUS_DRAFT)
                {
                    print '<a href="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '&amp;action=delmod&amp;rowid=' . $m->id . '">';
                    print img_delete();
                    print '</a>';
                }
                else
                {
                    print '&nbsp;';
                }

                print '</td>';  
                print '</tr>';            
            }
              
        }
        else
        {
            print '<tr class="oddeven">';
            print '<td align="left" colspan="6">';
            print $langs->trans('NoModFound');
            print '</td>';  
            print '</tr>'; 
        }
        

        print "</table>";
        print '</div>';
          
    }

    llxFooter();    
}

$db->close();

